#include <stdio.h>

static char version[] = "0.2.2 beta";

// 関数プロトタイプ
void help();

/*******************************************************************************
ヘルプ
*******************************************************************************/
void help()
{
	printf("バージョン %s\n", version);
	puts("使用方法 : snowcp [option] source dest");
	puts("sourceからdestへコピーする。optionとsourceは複数可。destが存在しない場合は自動的に作成する。");
	puts("");
	puts("オプション");
	puts(" -1 MODE    SHA-1で比較する。");
	puts("            MODEが1の場合はコピー直後に、");
	puts("            2の場合は全コピー終了後に比較する。");
	puts("            一致しなかった場合はdestを削除する。");
	puts("            (例 : snowcp -1 1 source dest)");
	puts("");
	puts(" -5 MODE    MD5で比較する。");
	puts("            MODEが1の場合はコピー直後に、");
	puts("            2の場合は全コピー終了後に比較する。");
	puts("            一致しなかった場合はdestを削除する。");
	puts("            (例 : snowcp -5 1 source dest)");
	puts("");
	puts(" -0         コンペアを行わない。");
	puts("            (-1、-5、-cオプションを無効にする。)");
	puts("");
	puts(" -b NUMBER  バッファの量を指定する（MB単位）。");
	puts("            (例 : snowcp -b 128 source dest)");
	puts("");
	puts(" -c MODE    memcmpで比較する。");
	puts("            MODEが1の場合はコピー直後に、");
	puts("            2の場合は全コピー終了後に比較する。");
	puts("            一致しなかった場合はdestを削除する。");
	puts("            (例 : snowcp -c 1 source dest)");
	puts("");
	puts(" -d         ダイレクトI/Oを使用する。");
	puts("            (このオプションは非推奨です。)");
	puts("");
	puts(" -i         ファイルを上書きする前に確認する。");
	puts("            (例 : snowcp -i source dest)");
	puts("");
//	puts(" -m         ファイルを移動する（未実装）。");
//	puts("");
	puts(" -n         ファイルを上書きしない。");
	puts("");
	puts(" -o         設定を保存する。");
	puts("");
	puts(" -v         コピー中のファイル名を表示する。");
	puts("");
	puts("注 : オプションは後に入力した方が優先される。例えば snowcp -in とした場合、-nオプションが有効になる。");
}
